var languageNames = {
"en-US": "Angol (USA)",
"am": "Amhara",
"ar": "Arab",
"ast": "Asztúriai",
"bg": "Bolgár",
"bn": "Bengáli",
"bn-IN": "Bengáli (India)",
"bo": "Tibeti",
"bs": "Bosnyák",
"ca": "Katalán",
"ca-valencia": "Valenciai katalán",
"cs": "Cseh",
"da": "Dán",
"de": "Német",
"dz": "Dzongkha",
"el": "Görök",
"en-GB": "Angol (Egyesült Királyság)",
"en-ZA": "English (Dél-Afrika)",
"eo": "Eszperantó",
"es": "Spanyol",
"et": "Észt",
"eu": "Baszk",
"fi": "Finn",
"fr": "Francia",
"gl": "Galíciai",
"gu": "Gudzsaráti",
"he": "Héber",
"hi": "Hindi",
"hr": "Horvát",
"hu": "Magyar",
"id": "Indonéz",
"is": "Izlandi",
"it": "Olasz",
"ja": "Japán",
"ka": "Grúz",
"km": "Khmer",
"ko": "Koreai",
"lo": "Lao",
"lt": "Litván",
"lv": "Lett",
"mk": "Macedón",
"nb": "Norvég bokmål",
"ne": "Nepáli",
"nl": "Holland",
"nn": "Norvég nynorsk",
"om": "Oromo",
"pl": "Lengyel",
"pt": "Portugál",
"pt-BR": "Brazíliai portugál",
"ro": "Román",
"ru": "Orosz",
"si": "Szingaléz",
"sid": "Szidamo",
"sk": "Szlovák",
"sl": "Szlovén",
"sq": "Albán",
"sv": "Svéd",
"ta": "Tamil",
"tg": "Tádzsik",
"tr": "Török",
"ug": "Ujgur",
"uk": "Ukrán",
"vi": "Vietnami",
"zh-CN": "Kínai (egyszerűsített)",
"zh-TW": "Kínai (hagyományos)",
};
